@@ -31,27 +31,32 @@
 
 
 /*
- * $Id: machine.h,v 1.36 2006/03/27 23:29:03 abe Exp $
+ * $Id: machine.h,v 1.38 2010/07/29 16:04:28 abe Exp $
  */
 
 
 #if	!defined(LSOF_MACHINE_H)
 #define	LSOF_MACHINE_H	1
 
-
 #include <sys/types.h>
 
+# if	defined(HAS_CONF_MINOR)
+#undef	minor
+# endif	/* defined(HAS_CONF_MINOR) */
+
 #if	defined(HASCPUMASK_T)
 /*
- * In FreeBSD >= 5.2 when the cpumask_t typedef is present, it is defined int
- * <sys/types.h> only if _KERNEL is predefined.  However, predefining _KERNEL
- * before #include'ing <sys/types.h> causes redefinition errors for boolean_t
- * and vm_page_t when <vm/vm.h> is #include'd with _KERNEL predefined.  Since
- * lsof must have _KERNEL predefined when <vm/vm.h> is #include'd, the
- * expedient choice is made to duplicate the cpumask_t typedef here.
+ * In FreeBSD >= 5.2 when the cpumask_t typedef is present, it may be defined
+ * in <sys/types.h> only if _KERNEL is predefined.  However, predefining
+ * _KERNEL before #include'ing <sys/types.h> causes redefinition errors for
+ * boolean_t and vm_page_t when <vm/vm.h> is #include'd with _KERNEL
+ * predefined.  Since lsof must have _KERNEL predefined when <vm/vm.h> is
+ * #include'd, the expedient choice is made to duplicate the cpumask_t typedef
+ * here.
  *
  * Note: the Configure script defines HASCPUMASK_T if <sys/types.h> and
- * <machine/_types.h> both have cpumask_t references.
+ * <machine/_types.h> both have cpumask_t references and if the reference in
+ * <sys/types.h> is valid only when _KERNEL is defined.
  */
 
 typedef	__cpumask_t	cpumask_t;
@@ -473,6 +478,13 @@ typedef	__cpumask_t	cpumask_t;
 /* #define	HASSNODE	1 */
 
 
+/*
+ * HASTASKS is defined for those dialects that have task reporting support.
+ */
+
+/* #define	HASTASKS	1 */
+
+
 /*
  * HASSOOPT, HASSOSTATE and HASTCPOPT define the availability of information
  * on socket options (SO_* symbols), socket states (SS_* symbols) and TCP
@@ -525,6 +537,15 @@ typedef	__cpumask_t	cpumask_t;
 /* #define	HASTCPTPIW	1 */
 
 
+/*
+ * HASTCPUDPSTATE is defined for dialects that have TCP and UDP state
+ * support -- i.e., for the "-stcp|udp:state" option and its associated
+ * speed improvements.
+ */
+
+#define	HASTCPUDPSTATE	1
+
+
 /*
  * HASTMPNODE is defined for those dialects that have tmpnodes.
  */
