@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dfile.c,v 1.13 2001/02/28 17:33:43 abe Exp $";
+static char *rcsid = "$Id: dfile.c,v 1.14 2001/08/14 13:27:16 abe Exp $";
 #endif
 
 #if	defined(HPUXKERNBITS) && HPUXKERNBITS>=64
@@ -82,7 +82,8 @@ print_dev(lf, dev)
 {
 	static char buf[128];
 
-	(void) snpf(buf, sizeof(buf), "%d,%#x", major(*dev), minor(*dev));
+	(void) snpf(buf, sizeof(buf), "%d,%#x", GET_MAJ_DEV(*dev),
+		    GET_MIN_DEV(*dev));
 	return(buf);
 }
 
