@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dmnt.c,v 1.11 2004/12/30 18:42:24 abe Exp $";
+static char *rcsid = "$Id: dmnt.c,v 1.12 2005/08/08 19:53:24 abe Exp $";
 #endif
 
 
@@ -177,7 +177,7 @@ no_space_for_mount:
 	    mtp->next = Lmi;
 	    mtp->dev = sb.st_dev;
 	    mtp->rdev = sb.st_rdev;
-	    mtp->inode = sb.st_ino;
+	    mtp->inode = (INODETYPE)sb.st_ino;
 	    mtp->mode = sb.st_mode;
 	/*
 	 * Interpolate a possible file system (mounted-on) device name link.
