@@ -33,6 +33,12 @@
 /*
  * The caller must define CVFS_DEVSAVE to have the device number moved
  * from the mounts entry to the local vfs structure.
+ *
+ * The caller must define CVFS_NLKSAVE to have the link count moved from
+ * the mounts entry to the local vfs structure.
+ *
+ * The caller must define CVFS_SZSAVE to have the size moved from the
+ * mounts entry to the local vfs structure.
  */
 
 
@@ -43,7 +49,7 @@
 # if	!defined(lint)
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: cvfs.c,v 1.3 98/03/24 10:38:47 abe Exp $";
+static char *rcsid = "$Id: cvfs.c,v 1.6 2008/10/21 16:12:36 abe Exp $";
 # endif	/* !defined(lint) */
 
 #include	"../lsof.h"
@@ -75,6 +81,14 @@ completevfs(vfs, dev)
 		vfs->dev = mp->dev;
 # endif	/* defined(CVFS_DEVSAVE) */
 
+# if	defined(CVFS_NLKSAVE)
+		vfs->nlink = mp->nlink;
+# endif	/* defined(CVFS_NLKSAVE) */
+
+# if	defined(CVFS_SZSAVE)
+		vfs->size = mp->size;
+# endif	/* defined(CVFS_SZSAVE) */
+
 		vfs->dir = mp->dir;
 		vfs->fsname = mp->fsname;
 
@@ -82,10 +96,15 @@ completevfs(vfs, dev)
 		vfs->fs_ino = mp->inode;
 # endif	/* defined(HASFSINO) */
 
+# if	defined(HASMNTSTAT)
+		vfs->mnt_stat = mp->stat;
+# endif	/* defined(HASMNTSTAT) */
+
+
 		return;
 	    }
 	}
 }
 #else	/* !defined(USE_LIB_COMPLETEVFS) */
-static char d1[] = "d"; static char *d2 = d1;
+char cvfs_d1[] = "d"; char *cvfs_d2 = cvfs_d1;
 #endif	/* defined(USE_LIB_COMPLETEVFS) */
