@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: print.c,v 1.47 2006/03/27 23:04:25 abe Exp $";
+static char *rcsid = "$Id: print.c,v 1.54 2012/04/10 16:30:51 abe Exp $";
 #endif
 
 
@@ -68,6 +68,13 @@ struct porttab {
 };
 
 
+#if	defined(HASNORPC_H)
+static struct porttab **Pth[2] = { NULL, NULL };
+						/* port hash buckets:
+						 * Pth[0] for TCP service names
+						 * Pth[1] for UDP service names
+						 */
+#else	/* !defined(HASNORPC_H) */
 static struct porttab **Pth[4] = { NULL, NULL, NULL, NULL };
 						/* port hash buckets:
 						 * Pth[0] for TCP service names
@@ -75,15 +82,20 @@ static struct porttab **Pth[4] = { NULL, NULL, NULL, NULL };
 						 * Pth[2] for TCP portmap info
 						 * Pth[3] for UDP portmap info
 						 */
+#endif	/* defined(HASNORPC_H) */
+
 #define HASHPORT(p)	(((((int)(p)) * 31415) >> 3) & (PORTHASHBUCKETS - 1))
 
 
+#if	!defined(HASNORPC_H)
 _PROTOTYPE(static void fill_portmap,(void));
+_PROTOTYPE(static void update_portmap,(struct porttab *pt, char *pn));
+#endif	/* !defined(HASNORPC_H) */
+
 _PROTOTYPE(static void fill_porttab,(void));
 _PROTOTYPE(static char *lkup_port,(int p, int pr, int src));
 _PROTOTYPE(static char *lkup_svcnam,(int h, int p, int pr, int ss));
 _PROTOTYPE(static int printinaddr,(void));
-_PROTOTYPE(static void update_portmap,(struct porttab *pt, char *pn));
 
 
 /*
@@ -104,6 +116,7 @@ endnm(sz)
 }
 
 
+#if !defined(HASNORPC_H)
 /*
  * fill_portmap() -- fill the RPC portmap program name table via a conversation
  *		     with the portmapper
@@ -267,6 +280,7 @@ fill_portmap()
 	}
 	clnt_destroy(c);
 }
+#endif	/* !defined(HASNORPC_H) */
 
 
 /*
@@ -468,7 +482,13 @@ lkup_port(p, pr, src)
  * If the hash buckets haven't been allocated, do so.
  */
 	if (!Pth[0]) {
+
+#if	defined(HASNORPC_H)
+	    nh = 2;
+#else	/* !defined(HASNORPC_H) */
 	    nh = FportMap ? 4 : 2;
+#endif	/* defined(HASNORPC_H) */
+
 	    for (h = 0; h < nh; h++) {
 		if (!(Pth[h] = (struct porttab **)calloc(PORTHASHBUCKETS,
 				sizeof(struct porttab *))))
@@ -483,6 +503,8 @@ lkup_port(p, pr, src)
 		}
 	    }
 	}
+
+#if	!defined(HASNORPC_H)
 /*
  * If we're looking up program names for portmapped ports, make sure the
  * portmap table has been loaded.
@@ -491,11 +513,15 @@ lkup_port(p, pr, src)
 	    (void) fill_portmap();
 	    pm++;
 	}
+#endif	/* !defined(HASNORPC_H) */
+
 /*
  * Hash the port and see if its name has been cached.  Look for a local
  * port first in the portmap, if portmap searching is enabled.
  */
 	h = HASHPORT(p);
+
+#if	!defined(HASNORPC_H)
 	if (!src && FportMap) {
 	    for (pt = Pth[pr+2][h]; pt; pt = pt->next) {
 		if (pt->port != p)
@@ -511,6 +537,8 @@ lkup_port(p, pr, src)
 		return(pt->name);
 	    }
 	}
+#endif	/* !defined(HASNORPC_H) */
+
 	for (pt = Pth[pr][h]; pt; pt = pt->next) {
 	    if (pt->port == p)
 		return(pt->name);
@@ -649,11 +677,21 @@ print_file()
 	    (void) printf("%-*.*s %*s", CmdColW, CmdColW, CMDTTL, PidColW,
 		PIDTTL);
 
+#if	defined(HASTASKS)
+	    if (TaskPrtFl)
+		(void) printf(" %*s", TidColW, TIDTTL);
+#endif	/* defined(HASTASKS) */
+
 #if	defined(HASZONES)
 	    if (Fzone)
-	        (void) printf(" %-*s", ZoneColW, ZONETTL);
+		(void) printf(" %-*s", ZoneColW, ZONETTL);
 #endif	/* defined(HASZONES) */
 
+#if	defined(HASSELINUX)
+	    if (Fcntx)
+		(void) printf(" %-*s", CntxColW, CNTXTTL);
+#endif /* defined(HASSELINUX) */
+
 #if	defined(HASPPID)
 	    if (Fppid)
 	 	(void) printf(" %*s", PpidColW, PPIDTTL);
@@ -726,6 +764,25 @@ print_file()
 	} else
 	    (void) printf(" %*d", PidColW, Lp->pid);
 
+#if	defined(HASTASKS)
+/*
+ * Size or print task ID.
+ */
+	if (!PrPass) {
+	    if (Lp->tid) {
+		(void) snpf(buf, sizeof(buf), "%d", Lp->tid);
+		if ((len = strlen(buf)) > TidColW)
+		    TidColW = len;
+		TaskPrtFl = 1;
+	    }
+	} else if (TaskPrtFl) {
+	    if (Lp->tid)
+		(void) printf(" %*d", TidColW, Lp->tid);
+	    else
+		(void) printf(" %*s", TidColW, "");
+	}
+#endif	/* defined(HASTASKS) */
+
 #if	defined(HASZONES)
 /*
  * Size or print the zone.
@@ -741,6 +798,21 @@ print_file()
 	}
 #endif	/* defined(HASZONES) */
 
+#if	defined(HASSELINUX)
+/*
+ * Size or print the context.
+ */
+	if (Fcntx) {
+	    if (!PrPass) {
+		if (Lp->cntx) {
+		    if ((len = strlen(Lp->cntx)) > CntxColW)
+			CntxColW = len;
+		}
+	    } else
+		(void) printf(" %-*s", CntxColW, Lp->cntx ? Lp->cntx : "");
+	}
+#endif	/* defined(HASSELINUX) */
+
 #if	defined(HASPPID)
 	if (Fppid) {
 
@@ -886,7 +958,7 @@ print_file()
 #if	defined(HASPRINTDEV)
 	    cp = HASPRINTDEV(Lf, &dev);
 #else	/* !defined(HASPRINTDEV) */
-	    (void) snpf(buf, sizeof(buf), "%d,%d", GET_MAJ_DEV(dev),
+	    (void) snpf(buf, sizeof(buf), "%u,%u", GET_MAJ_DEV(dev),
 		GET_MIN_DEV(dev));
 	    cp = buf;
 #endif	/* defined(HASPRINTDEV) */
@@ -1110,7 +1182,14 @@ addr_too_long:
 	 * Process the port number.
 	 */
 	    if (Lf->li[i].p > 0) {
-		if (Fport || FportMap) {
+
+		if (Fport
+
+#if	!defined(HASNORPC_H)
+		||  FportMap
+#endif	/* defined(HASNORPC_H) */
+
+		) {
 
 		/*
 		 * If converting port numbers to service names, or looking
@@ -1123,9 +1202,10 @@ addr_too_long:
 		 * loopback address 127.0.0.1.  (Test 2 may not always work
 		 * -- e.g., on hosts with multiple interfaces.)
 		 */
+#if	!defined(HASNORPC_H)
 		    if ((src = i) && FportMap) {
 
-#if	defined(HASIPv6)
+# if	defined(HASIPv6)
 			if (Lf->li[0].af == AF_INET6) {
 			    if (IN6_IS_ADDR_LOOPBACK(&Lf->li[i].ia.a6)
 			    ||  IN6_ARE_ADDR_EQUAL(&Lf->li[0].ia.a6,
@@ -1133,15 +1213,17 @@ addr_too_long:
 			    )
 				src = 0;
 			} else
-#endif	/* defined(HASIPv6) */
+# endif	/* defined(HASIPv6) */
 
 			if (Lf->li[0].af == AF_INET) {
-			    if (Lf->li[i].ia.a4.s_addr == INADDR_LOOPBACK
+			    if (Lf->li[i].ia.a4.s_addr == htonl(INADDR_LOOPBACK)
 			    ||  Lf->li[0].ia.a4.s_addr == Lf->li[1].ia.a4.s_addr
 			    )
 				src = 0;
 			}
 		    }
+#endif	/* !defined(HASNORPC_H) */
+
 		    if (strcasecmp(Lf->iproto, "TCP") == 0)
 			port = lkup_port(Lf->li[i].p, 0, src);
 		    else if (strcasecmp(Lf->iproto, "UDP") == 0)
@@ -1208,6 +1290,12 @@ print_init()
 	    SzOffColW = strlen(OFFTTL);
 	else
 	    SzOffColW = strlen(SZOFFTTL);
+	TaskPrtFl = 0;
+
+#if	defined(HASTASKS)
+	TidColW = strlen(TIDTTL);
+#endif	/* defined(HASTASKS) */
+
 	TypeColW = strlen(TYPETTL);
 	UserColW = strlen(USERTTL);
 
@@ -1230,6 +1318,11 @@ print_init()
 # endif	/* !defined(HASNOFSNADDR) */
 #endif	/* defined(HASFSTRUCT) */
 
+#if	defined(HASSELINUX)
+	if (Fcntx)
+	    CntxColW = strlen(CNTXTTL);
+#endif	/* defined(HASSELINUX) */
+
 #if	defined(HASZONES)
 	if (Fzone)
 	    ZoneColW = strlen(ZONETTL);
@@ -2108,8 +2201,7 @@ print_nma:
 	)) {
 	    if (ps)
 		putchar(' ');
-	    (void) print_tcptpi(1);
-	    return;
+	    (void) print_tcptpi(0);
 	}
 	if (nl)
 	    putchar('\n');
@@ -2269,7 +2361,7 @@ printuid(uid, ty)
 			}
 		    }
 		    sbs = sb;
-	        }
+		}
 		CkPasswd = 0;
 	    }
 	/*
@@ -2693,6 +2785,7 @@ printunkaf(fam, ty)
 }
 
 
+#if	!defined(HASNORPC_H)
 /*
  * update_portmap() - update a portmap entry with its port number or service
  *		      name
@@ -2725,3 +2818,4 @@ update_portmap(pt, pn)
 	pt->nl = nl;
 	pt->ss = 1;
 }
+#endif	/* !defined(HASNORPC_H) */
