@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: store.c,v 1.35 2005/08/08 19:44:35 abe Exp $";
+static char *rcsid = "$Id: store.c,v 1.40 2011/09/07 19:13:49 abe Exp $";
 #endif
 
 
@@ -63,9 +63,20 @@ int CmdColW;			/* COMMAND column width */
 struct str_lst *Cmdl = (struct str_lst *)NULL;
 				/* command names selected with -c */
 int CmdLim = CMDL;		/* COMMAND column width limit */
+int Cmdni = 0;			/* command name inclusions selected with -c */
+int Cmdnx = 0;			/* command name exclusions selected with -c */
 lsof_rx_t *CmdRx = (lsof_rx_t *)NULL;
 				/* command regular expression table */
 
+#if	defined(HASSELINUX)
+cntxlist_t *CntxArg = (cntxlist_t *)NULL;
+				/* security context arguments supplied with
+				 * -Z */
+int CntxColW;			/* security context column width */
+int CntxStatus = 0;		/* security context status: 0 == disabled,
+				 * 1 == enabled */
+#endif	/* defined(HASSELINUX) */
+
 #if	defined(HASDCACHE)
 unsigned DCcksum;		/* device cache file checksum */
 int DCfd = -1;			/* device cache file descriptor */
@@ -110,11 +121,15 @@ struct l_dev *Devtp = (struct l_dev *)NULL;
 char **Dstk = (char **)NULL;	/* the directory stack */
 int Dstkx = 0;			/* Dstk[] index */
 int Dstkn = 0;			/* Dstk[] entries allocated */
-
+efsys_list_t *Efsysl = (efsys_list_t *)NULL;
+				/* file systems for which kernel blocks are
+				 * to be eliminated */
 int ErrStat = 0;		/* path stat() error count */
 uid_t Euid;			/* effective UID of this lsof process */
 int Fand = 0;			/* -a option status */
 int Fblock = 0;			/* -b option status */
+int FcColW;			/* FCT column width */
+int Fcntx = 0;			/* -Z option status */
 int FdColW;			/* FD column width */
 int Ffilesys = 0;		/* -f option status:
 				 *    0 = paths may be file systems
@@ -127,6 +142,7 @@ int NcacheReload = 1;		/* 1 == call ncache_load() */
 #endif	/* defined(HASNCACHE) */
 
 int Ffield = 0;			/* -f and -F status */
+int FgColW;			/* FILE-FLAG column width */
 int Fhelp = 0;			/* -h option status */
 int Fhost = 1;			/* -H option status */
 int Fnet = 0;			/* -i option status: 0==none
@@ -142,20 +158,22 @@ int Foffset = 0;		/* -o option status */
 int Fovhd = 0;			/* -O option status */
 int Fport = 1;			/* -P option status */
 
-#if	defined(HASPMAPENABLED)
+#if	!defined(HASNORPC_H)
+# if	defined(HASPMAPENABLED)
 int FportMap = 1;		/* +|-M option status */
-#else	/* !defined(HASPMAPENABLED) */
+# else	/* !defined(HASPMAPENABLED) */
 int FportMap = 0;		/* +|-M option status */
-#endif	/* defined(HASPMAPENABLED) */
+# endif	/* defined(HASPMAPENABLED) */
+#endif	/* !defined(HASNORPC_H) */
 
 int Fpgid = 0;			/* -g option status */
 int Fppid = 0;			/* -R option status */
 int Fsize = 0;			/* -s option status */
-int FcColW;			/* FCT column width */
-int FgColW;			/* FILE-FLAG column width */
 int FsColW;			/* FSTR-ADDR column width */
 int Fsv = FSV_DEFAULT;		/* file struct value selections */
+int FsvByf = 0;			/* Fsv was set by +f */
 int FsvFlagX = 0;		/* hex format status for FSV_FG */
+int Ftask = 0;			/* -K option value */
 int NiColW;			/* NODE-ID column width */
 char *NiTtl = NITTL;		/* NODE-ID column title */
 int Ftcptpi = TCPTPI_STATE;	/* -T option status */
@@ -194,61 +212,26 @@ struct fieldsel FieldSel[] = {
     { LSOF_FID_FG,     0,  LSOF_FNM_FG,     &Fsv,     FSV_FG	 }, /*  7 */
     { LSOF_FID_INODE,  0,  LSOF_FNM_INODE,  NULL,     0		 }, /*  8 */
     { LSOF_FID_NLINK,  0,  LSOF_FNM_NLINK,  &Fnlink,  1		 }, /*  9 */
-    { LSOF_FID_LOCK,   0,  LSOF_FNM_LOCK,   NULL,     0		 }, /* 10 */
-    { LSOF_FID_LOGIN,  0,  LSOF_FNM_LOGIN,  NULL,     0		 }, /* 11 */
-    { LSOF_FID_MARK,   1,  LSOF_FNM_MARK,   NULL,     0		 }, /* 12 */
-    { LSOF_FID_NAME,   0,  LSOF_FNM_NAME,   NULL,     0		 }, /* 13 */
-    { LSOF_FID_NI,     0,  LSOF_FNM_NI,     &Fsv,     FSV_NI	 }, /* 14 */
-    { LSOF_FID_OFFSET, 0,  LSOF_FNM_OFFSET, NULL,     0		 }, /* 15 */
-    { LSOF_FID_PID,    1,  LSOF_FNM_PID,    NULL,     0		 }, /* 16 */
-    { LSOF_FID_PGID,   0,  LSOF_FNM_PGID,   &Fpgid,   1		 }, /* 17 */
-    { LSOF_FID_PROTO,  0,  LSOF_FNM_PROTO,  NULL,     0		 }, /* 18 */
-    { LSOF_FID_RDEV,   0,  LSOF_FNM_RDEV,   NULL,     0		 }, /* 19 */
-    { LSOF_FID_PPID,   0,  LSOF_FNM_PPID,   &Fppid,   1		 }, /* 20 */
-    { LSOF_FID_SIZE,   0,  LSOF_FNM_SIZE,   NULL,     0		 }, /* 21 */
-    { LSOF_FID_STREAM, 0,  LSOF_FNM_STREAM, NULL,     0		 }, /* 22 */
-    { LSOF_FID_TYPE,   0,  LSOF_FNM_TYPE,   NULL,     0		 }, /* 23 */
-    { LSOF_FID_TCPTPI, 0,  LSOF_FNM_TCPTPI, &Ftcptpi, TCPTPI_ALL }, /* 24 */
-    { LSOF_FID_UID,    0,  LSOF_FNM_UID,    NULL,     0		 }, /* 25 */
-    { LSOF_FID_ZONE,   0,  LSOF_FNM_ZONE,   &Fzone,   1		 }, /* 26 */
-    { LSOF_FID_TERM,   0,  LSOF_FNM_TERM,   NULL,     0		 }, /* 27 */
-
-#if	defined(HASFIELDAP1)
-    { '1',	       0,  HASFIELDAP1,     NULL,     0		 }, /* TERM+1 */
-#endif	/* defined(HASFIELDAP1) */
-
-#if	defined(HASFIELDAP2)
-    { '2',	       0,  HASFIELDAP2,     NULL,     0		 }, /* TERM+2 */
-#endif	/* defined(HASFIELDAP2) */
-
-#if	defined(HASFIELDAP3)
-    { '3',	       0,  HASFIELDAP3,     NULL,     0		 }, /* TERM+3 */
-#endif	/* defined(HASFIELDAP3) */
-
-#if	defined(HASFIELDAP4)
-    { '4',	       0,  HASFIELDAP4,     NULL,     0		 }, /* TERM+4 */
-#endif	/* defined(HASFIELDAP4) */
-
-#if	defined(HASFIELDAP5)
-    { '5',	       0,  HASFIELDAP5,     NULL,     0		 }, /* TERM+5 */
-#endif	/* defined(HASFIELDAP5) */
-
-#if	defined(HASFIELDAP6)
-    { '6',	       0,  HASFIELDAP6,     NULL,     0		 }, /* TERM+6 */
-#endif	/* defined(HASFIELDAP6) */
-
-#if	defined(HASFIELDAP7)
-    { '7',	       0,  HASFIELDAP7,     NULL,     0		 }, /* TERM+7 */
-#endif	/* defined(HASFIELDAP7) */
-
-#if	defined(HASFIELDAP8)
-    { '8',	       0,  HASFIELDAP8,     NULL,     0		 }, /* TERM+8 */
-#endif	/* defined(HASFIELDAP8) */
-
-#if	defined(HASFIELDAP9)
-    { '9',	       0,  HASFIELDAP9,     NULL,     0		 }, /* TERM+9 */
-#endif	/* defined(HASFIELDAP9) */
-
+    { LSOF_FID_TID,    0,  LSOF_FNM_TID,    NULL,     0		 }, /* 11 */
+    { LSOF_FID_LOCK,   0,  LSOF_FNM_LOCK,   NULL,     0		 }, /* 11 */
+    { LSOF_FID_LOGIN,  0,  LSOF_FNM_LOGIN,  NULL,     0		 }, /* 12 */
+    { LSOF_FID_MARK,   1,  LSOF_FNM_MARK,   NULL,     0		 }, /* 13 */
+    { LSOF_FID_NAME,   0,  LSOF_FNM_NAME,   NULL,     0		 }, /* 14 */
+    { LSOF_FID_NI,     0,  LSOF_FNM_NI,     &Fsv,     FSV_NI	 }, /* 15 */
+    { LSOF_FID_OFFSET, 0,  LSOF_FNM_OFFSET, NULL,     0		 }, /* 16 */
+    { LSOF_FID_PID,    1,  LSOF_FNM_PID,    NULL,     0		 }, /* 17 */
+    { LSOF_FID_PGID,   0,  LSOF_FNM_PGID,   &Fpgid,   1		 }, /* 18 */
+    { LSOF_FID_PROTO,  0,  LSOF_FNM_PROTO,  NULL,     0		 }, /* 19 */
+    { LSOF_FID_RDEV,   0,  LSOF_FNM_RDEV,   NULL,     0		 }, /* 20 */
+    { LSOF_FID_PPID,   0,  LSOF_FNM_PPID,   &Fppid,   1		 }, /* 21 */
+    { LSOF_FID_SIZE,   0,  LSOF_FNM_SIZE,   NULL,     0		 }, /* 22 */
+    { LSOF_FID_STREAM, 0,  LSOF_FNM_STREAM, NULL,     0		 }, /* 23 */
+    { LSOF_FID_TYPE,   0,  LSOF_FNM_TYPE,   NULL,     0		 }, /* 24 */
+    { LSOF_FID_TCPTPI, 0,  LSOF_FNM_TCPTPI, &Ftcptpi, TCPTPI_ALL }, /* 25 */
+    { LSOF_FID_UID,    0,  LSOF_FNM_UID,    NULL,     0		 }, /* 26 */
+    { LSOF_FID_ZONE,   0,  LSOF_FNM_ZONE,   &Fzone,   1		 }, /* 27 */
+    { LSOF_FID_CNTX,   0,  LSOF_FNM_CNTX,   &Fcntx,   1		 }, /* 28 */
+    { LSOF_FID_TERM,   0,  LSOF_FNM_TERM,   NULL,     0		 }, /* 29 */
     { ' ',	       0,  NULL,	    NULL,     0		 }
 };
 
@@ -358,9 +341,40 @@ char *SzOffFmt_dv = (char *)NULL;
 				/* SZOFFTYPE %*d printf  specification */
 char *SzOffFmt_x = (char *)NULL;
 				/* SZOFFTYPE %#x printf  specification */
+int TaskPrtFl = 0;		/* task print flag */
+int TcpStAlloc = 0;		/* allocated (possibly unused) entries in TCP 
+				 * state tables */
+unsigned char *TcpStI = (unsigned char *)NULL;
+				/* included TCP states */
+int TcpStIn = 0;		/* number of entries in TcpStI[] */
+int TcpStOff = 0;		/* offset for TCP state number to adjust
+				 * negative numbers to an index into TcpSt[],
+				 * TcpStI[] and TcpStX[] */
+unsigned char *TcpStX = (unsigned char *)NULL;
+				/* excluded TCP states */
+int TcpStXn = 0;		/* number of entries in TcpStX[] */
+int TcpNstates = 0;		/* number of TCP states -- either in
+				 * tcpstates[] or TcpSt[] */
+char **TcpSt = (char **)NULL;	/* local TCP state names, indexed by system
+				 * state value */
 char Terminator = '\n';		/* output field terminator */
+int TidColW = 0;		/* TID column width */
 int TmLimit = TMLIMIT;		/* Readlink() and stat() timeout (seconds) */
 int TypeColW;			/* TYPE column width */
+int UdpStAlloc = 0;		/* allocated (possibly unused) entries in UDP 
+				 * state tables */
+unsigned char *UdpStI = (unsigned char *)NULL;
+				/* included UDP states */
+int UdpStIn = 0;		/* number of entries in UdpStI[] */
+int UdpStOff = 0;		/* offset for UDP state number to adjust
+				 * negative numbers to an index into UdpSt[],
+				 * UdpStI[] and UdpStX[] */
+unsigned char *UdpStX = (unsigned char *)NULL;
+				/* excluded UDP states */
+int UdpStXn = 0;		/* number of entries in UdpStX[] */
+int UdpNstates = 0;		/* number of UDP states  in UdpSt[] */
+char **UdpSt = (char **)NULL;	/* local UDP state names, indexed by system
+				 * state number */
 int UserColW;			/* USER column width */
 
 #if	defined(HASZONES)
